@@ -34,16 +34,16 @@ class APTDevice_DC(APTDevice):
     :param channels: Tuple of indices (1-based) for the controller bay's channels.
     """
 
-    def __init__(self, serial_port=None, serial_number="", home=True, invert_direction_logic=False, swap_limit_switches=False, controller=EndPoint.RACK, bays=(EndPoint.BAY0,), channels=(1,)):
+    def __init__(self, serial_port=None, vid=None, pid=None, manufacturer=None, product=None, serial_number=None, location=None, home=True, invert_direction_logic=False, swap_limit_switches=False, controller=EndPoint.RACK, bays=(EndPoint.BAY0,), channels=(1,)):
 
-        super().__init__(serial_port=serial_port, serial_number=serial_number, controller=controller, bays=bays, channels=channels)
+        super().__init__(serial_port=serial_port, vid=vid, pid=pid, manufacturer=manufacturer, product=product, serial_number=serial_number, location=location, controller=controller, bays=bays, channels=channels)
 
         self.invert_direction_logic = invert_direction_logic
         """
         On some devices, "forward" velocity moves towards negative encoder counts.
         If that seems opposite to what is expected, this flag allows inversion of that logic.
         This will also swap the meaning of the ``"moving_forward"`` and ``"moving_reverse"`` 
-        fields in the :data:`status` flags.
+        fields in the :data:`status_` flags.
         """
 
         self.swap_limit_switches = swap_limit_switches
@@ -184,7 +184,7 @@ class APTDevice_DC(APTDevice):
         indexes the channel.
 
         Keys are ``"jog_mode"``, ``"step_size"``, ``"min_velocity"``, ``"acceleration"``,
-        ``"max_velocity"``, and "stop_mode".
+        ``"max_velocity"``, and ``"stop_mode"``.
         """
         # Request current jog parameters
         for bay in self.bays:
